# MetaStats

MetaStats SDK examples have moved to [https://github.com/metaapi/metaapi-python-sdk/tree/main/examples/metastats](https://github.com/metaapi/metaapi-python-sdk/tree/main/examples/metastats).
